<?php

/**
 * @file
 * The admin file of the module.
 */

/**
 * Create the admin configuration form.
 */
function openam_admin_form() {
  $form = array();

  $form['openam_enabled'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable OpenAM'),
    '#default_value' => variable_get('openam_enabled', 0),
    '#description' => t('Activate OpenAM when a user trying to connect to Drupal.'),
    '#required' => FALSE,
  );

  $form['openam_cookie_name'] = array(
    '#type' => 'textfield',
    '#title' => t('OpenAM cookie name'),
    '#default_value' => variable_get('openam_cookie_name', ''),
    '#size' => 25,
    '#maxlength' => 64,
    '#description' => t('The cookie name from which user data will be retrieved.'),
    '#required' => TRUE,
  );

  $form['openam_server_url'] = array(
    '#type' => 'textfield',
    '#title' => t('OpenAM server URL'),
    '#default_value' => variable_get('openam_server_url', ''),
    '#size' => 64,
    '#maxlength' => 128,
    '#description' => t('The server URL of the open am, without trailing slash. <br/>For example : http://mydomain:8080/authservice'),
    '#required' => TRUE,
  );

  $form['openam_parameters'] = array(
    '#type' => 'textfield',
    '#title' => t('OpenAM server URL additionnal parameters'),
    '#default_value' => variable_get('openam_parameters', ''),
    '#size' => 64,
    '#maxlength' => 128,
    '#description' => t('Additional parameters to add to the request (for example, a REALM name)'),
    '#required' => FALSE,
  );

  $form['openam_attributes'] = array(
    '#type' => 'fieldset',
    '#title' => t('Attributes mapping'),
    '#collapsible' => TRUE,
  );

  $form['openam_attributes']['openam_username_attribute'] = array(
    '#type' => 'textfield',
    '#title' => t('Username'),
    '#default_value' => variable_get('openam_username_attribute', 'uid'),
    '#size' => 25,
    '#maxlength' => 64,
    '#description' => t('The name of the OpenAM profile attribute to use as the Drupal username. Use the default, <b>uid</b>, if users have the same username in Drupal and OpenAM.'),
    '#required' => TRUE,
  );

  $form['openam_attributes']['openam_mail_attribute'] = array(
    '#type' => 'textfield',
    '#title' => t('Mail'),
    '#default_value' => variable_get('openam_mail_attribute', ''),
    '#size' => 25,
    '#maxlength' => 64,
    '#description' => t('Define the OpenAM attribute for the field mail.'),
    '#required' => TRUE,
  );

  // Add a mapping for each user field.
  $fields = field_info_instances('user', 'user');
  foreach ($fields as $field_name => $field_data) {
    $form['openam_attributes']['openam_' . $field_name . '_attribute'] = array(
      '#type' => 'textfield',
      '#title' => $field_data['label'],
      '#default_value' => variable_get('openam_' . $field_name . '_attribute', ''),
      '#size' => 25,
      '#maxlength' => 64,
      '#description' => t('Define the OpenAM attribute for the field %field', array(
        '%field' => $field_data['label'],
      )),
      '#required' => FALSE,
    );
  }

  return system_settings_form($form);
}

/**
 * Validate the admin form.
 */
function openam_admin_form_validate($form, &$form_state) {

  // Get the server URL and check if it is valid.
  $server_url = $form_state['values']['openam_server_url'];
  if (!valid_url($server_url, true)) {
    form_set_error('openam_server_url', t('OpenAM Base URL is not a valid URL.'));
  }
  if (strpos($server_url, 'http') !== 0) {
    form_set_error('openam_server_url', t('OpenAM Base URL scheme must be http or https.'));
  }

  // Make sure the base URL not ends in a slash.
  if (substr($server_url, -1) == '/') {
    $form_state['values']['openam_server_url'] = substr($server_url, 0, drupal_strlen($server_url) - 1);
  }
}
